@@ -254,7 +254,7 @@ class EmailMessage:
         self.connection = connection
 
     def get_connection(self, fail_silently=False):
-        from mail import get_connection
+        from backend_base.mail import get_connection
         if not self.connection:
             self.connection = get_connection(fail_silently=fail_silently)
         return self.connection
